@@ -9,12 +9,15 @@ from etl import ETL
 from factory import factory
 from util import Util
 from version import __version__
-import argparse #apt-get install python-argparse
+import argparse  # apt-get install python-argparse
 import inspect
 import os
+import sys
+
 log = Util.get_log('main')
 
-def parse_args():
+
+def parse_args(args_list):
     log.info("Stetl version = %s" % __version__)
 
     argparser = argparse.ArgumentParser(description='Invoke Stetl')
@@ -25,28 +28,34 @@ def parse_args():
                            dest='config_section', required=False)
 
     argparser.add_argument('-a ', '--args', type=str,
-                           help='Arguments or .properties file to be substituted for {argN}s in config file, as -a "arg1=foo arg2=bar" or -a args.properties',
-                           dest='config_args', required=False)
+                           help='Arguments or .properties files to be substituted for symbolic {argN}s in Stetl config file,\
+                                as -a "arg1=foo arg2=bar" and/or -a args.properties, multiple -a options are possible',
+                           dest='config_args', required=False, action='append')
 
     argparser.add_argument('-d ', '--doc', type=str,
-                          help='Get component documentation like its configuration parameters, e.g. stetl doc stetl.inputs.fileinput.FileInput',
-                          dest='doc_args', required=False)
+                           help='Get component documentation like its configuration parameters, e.g. stetl doc stetl.inputs.fileinput.FileInput',
+                           dest='doc_args', required=False)
 
-    args = argparser.parse_args()
+    args = argparser.parse_args(args_list)
 
     if args.config_args:
-        if os.path.isfile(args.config_args):
-            log.info('Found args file at: %s' % args.config_args)
-            args.config_args = Util.propsfile_to_dict(args.config_args)
-        else:
-            # Convert string to dict: http://stackoverflow.com/a/1248990
-            args.config_args = Util.string_to_dict(args.config_args)
+        args_total = dict()
+        for arg in args.config_args:
+            if os.path.isfile(arg):
+                log.info('Found args file at: %s' % arg)
+                args_total = Util.merge_two_dicts(args_total, Util.propsfile_to_dict(arg))
+            else:
+                # Convert string to dict: http://stackoverflow.com/a/1248990
+                args_total = Util.merge_two_dicts(args_total, Util.string_to_dict(arg))
+
+        args.config_args = args_total
 
     return args
 
+
 # DEPRECATED, now using @Config which also documents with Sphinx
 def print_config_attrs(clazz):
-    skip =['Filter', 'Input', 'Output', 'Component']
+    skip = ['Filter', 'Input', 'Output', 'Component']
     for base in clazz.__bases__:
 
         if base.__name__ not in skip:
@@ -54,7 +63,6 @@ def print_config_attrs(clazz):
 
     """Print documentation for Attr object"""
 
-
     module_name, _, class_name = clazz.__name__.rpartition('.')
     # print 'From class: %s' % class_name
 
@@ -73,13 +81,14 @@ def print_config_attrs(clazz):
     if attr_count == 0:
         print ('No config attributes or class not yet documented')
 
+
 def print_classes(package):
     # is_module = inspect.ismodule(class_name)
     import inputs
     import pkgutil
-    package=inputs
+    package = inputs
     for importer, modname, ispkg in pkgutil.walk_packages(path=package.__path__,
-                                                          prefix=package.__name__+'.',
+                                                          prefix=package.__name__ + '.',
                                                           onerror=lambda x: None):
         print('stetl.' + modname)
         for name, data in inspect.getmembers(modname, inspect.isclass):
@@ -107,18 +116,21 @@ def print_doc(class_name):
         log.error("cannot print info class named '%s' e=%s - you made a typo?" % (class_name, str(e)))
         raise e
 
+
 def main():
     """The `main` function, to be called from commandline, like `python src/main.py -c etl.cfg`.
 
     Args:
        -c  --config <config_file>  the Stetl config file.
        -s  --section <section_name> the section in the Stetl config (ini) file to execute (default is [etl]).
-       -a  --args <arglist> substitutable args for symbolic, {arg}, values in Stetl config file, in format "arg1=foo arg2=bar" etc.
+       -a  --args <arglist> sero or more substitutable args for symbolic, {arg}, values in Stetl config file, in format -a arg1=foo -a arg2=bar etc.
        -d  --doc <class> Get component documentation like its configuration parameters, e.g. stetl --doc stetl.inputs.fileinput.FileInput
        -h  --help get help info
 
     """
-    args = parse_args()
+
+    # Pass arguments explicitly, facilitates testing
+    args = parse_args(sys.argv[1:])
 
     if args.config_file:
         # Do the ETL
@@ -130,5 +142,6 @@ def main():
     else:
         print('Unknown option, try stetl -h for help')
 
+
 if __name__ == "__main__":
     main()
