@@ -7,6 +7,7 @@
 from util import etree
 import json
 
+
 class Packet:
     """
     Represents units of (any) data and status passed along Chain of Components.
@@ -56,6 +57,7 @@ class Packet:
             s = str(self.data)
         return s
 
+
 # Simple enum emulation NOT ANY MORE: TOO INVOLVED AND INFLEXIBLE: use Strings with predefined ones in FORMAT.*
 # See http://stackoverflow.com/questions/1969005/enumerations-in-python
 # class Enum(object):
@@ -68,6 +70,29 @@ class Packet:
 
 
 class FORMAT:
+    """
+    Format of Packet (enumeration).
+
+    Current possible values:
+
+    * 'none'
+    * 'xml_line_stream'
+    * 'line_stream'
+    * 'etree_doc'
+    * 'etree_element'
+    * 'etree_feature_array'
+    * 'xml_doc_as_string'
+    * 'string'
+    * 'record'
+    * 'record_array'
+    * 'struct'
+    * 'geojson_feature'
+    * 'geojson_collection'
+    * 'ogr_feature'
+    * 'ogr_feature_array'
+    * 'any'
+
+    """
     none = 'none'
     xml_line_stream = 'xml_line_stream'
     line_stream = 'line_stream'
